@@ -299,14 +299,14 @@ def Planck(T, WVNM):
 
     Parameters
     ----------
-    T : float or 1darray
+    T : float or array
         Temperatures in kelvin.
     WVNM : float
         Wavenumber with units m^-1.
 
     Returns
     -------
-    float or 1darray
+    float or array
         Emitted power per unit area from a blackbody surface with units W / m^2.
 
     """
@@ -325,14 +325,15 @@ def Planck(T, WVNM):
     
 
 def blackbody_contrib_to_BCs(T, WVNMLO, WVNMHI, **kwargs):
-    """Compute blackbody contribution to the BCs (``b_pos`` or ``b_neg``).
+    """Compute blackbody contribution to each BC (``b_pos`` or ``b_neg``), 
+    i.e. the blackbody emission of that boundary, with units W / m^2.
     This convenience function is provided to help match the inputs for Stamnes' DISORT to those for PythonicDISORT.
     Users will have to manually adjust emissivities but ``PythonicDISORT.subroutines.generate_emissivity_from_BDRF``
     can help with that.
     
     Parameters
     ----------
-    T : float or 1darray
+    T : float or array
         Temperatures in kelvin.
     WVNMLO : float
         Lower bound of wavenumber interval with units m^-1. This variable is identically named in Stamnes' DISORT.
@@ -341,6 +342,10 @@ def blackbody_contrib_to_BCs(T, WVNMLO, WVNMHI, **kwargs):
     **kwargs
         Keyword arguments to pass to ``scipy.integrate.quad_vec``.
         
+    Returns
+    -------
+    float or array
+        The blackbody emission of each boundary with units W / m^2.
     """ 
     return np.squeeze(sc.integrate.quad_vec(lambda WVNM: Planck(T, WVNM), WVNMLO, WVNMHI, **kwargs)[0])
 
@@ -351,15 +356,15 @@ def linear_spline_coefficients(x, y, check_inputs=True):
 
     Parameters
     ----------
-    x : 1darray
+    x : array
         Array of `x` data points.
-    y : 1darray
+    y : array
         Array of `y` data points.
 
     Returns
     -------
     2darray
-        The coefficients with axes (segment, ascending polynomial order), as required by ``pydisort``.
+        The coefficients with axes (segment, ascending polynomial order) which is required by ``pydisort``.
 
     """
     # Input checks
@@ -379,15 +384,16 @@ def linear_spline_coefficients(x, y, check_inputs=True):
 
 
 def generate_s_poly_coeffs(tau_arr, TEMPER, WVNMLO, WVNMHI, **kwargs):
-    """Generate ``s_poly_coeffs`` as required by ``pydisort``.
-    This convenience function is provided to help match the inputs for Stamnes' DISORT to those for PythonicDISORT,
-    however, users will have to manually adjust emissivities.
+    """Generate DISORT-equivalent ``s_poly_coeffs`` for input into ``pydisort``.
+    This convenience function is provided to help match the inputs for Stamnes' DISORT to those for PythonicDISORT.
+    Users will have to manually adjust emissivities, however, and they should note that PythonicDISORT allows much
+    more flexibility in choosing blackbody emission profiles than DISORT.
     
     Parameters
     ----------
     tau_arr : array or float
         Optical depth of the lower boundary of each atmospheric layer.
-    TEMPER : 1darray
+    TEMPER : array
         Temperature in kelvin at each boundary / interface from top to bottom.
         This variable is identically named in Stamnes' DISORT.
     WVNMLO : float
@@ -419,7 +425,7 @@ def generate_s_poly_coeffs(tau_arr, TEMPER, WVNMLO, WVNMHI, **kwargs):
 def generate_emissivity_from_BDRF(N, zeroth_BDRF_Fourier_mode):
     """Use Kirchoff's law of thermal radiation to determine the (directional) emissivity 
     of the surface given the zeroth Fourier mode of the Bi-Directional Reflectance Function (BDRF).
-    This computation is internal to Stamnes' DISORT.
+    This computation is automatic and internal to Stamnes' DISORT.
     This function supplements ``PythonicDISORT.subroutines.blackbody_contrib_to_BCs``.
     
     Parameters
@@ -432,8 +438,8 @@ def generate_emissivity_from_BDRF(N, zeroth_BDRF_Fourier_mode):
 
     Returns
     -------
-    1darray
-        Emissivity for the blackbody contribution to the lower boundary source `b_neg``.
+    array
+        Emissivity for the blackbody contribution to the lower boundary source ``b_neg``.
     """
     mu_arr_pos, W = Gauss_Legendre_quad(N)
     return 1 - 2 * zeroth_BDRF_Fourier_mode(mu_arr_pos, mu_arr_pos) * mu_arr_pos[None, :] @ W
@@ -488,9 +494,9 @@ def affine_transform_poly_coeffs(poly_coeffs, a_arr, b_arr):
     poly_coeffs : 2darray
         Array with columns [C_0, C_1, ..., C_n]. 
         The rows correspond to different affine transformations.
-    a_arr : 1darray
+    a_arr : array
         Scale factors.
-    b_arr : 1darray
+    b_arr : array
         Translations.
 
     Returns
@@ -518,10 +524,11 @@ def affine_transform_poly_coeffs(poly_coeffs, a_arr, b_arr):
     return np.einsum("lij, lj -> li", T, poly_coeffs, optimize=True)
 
 
+
 def interpolate(u):
-    """Polynomial (Barycentric) interpolation with respect to mu. The output 
-    is a function that is continuous and variable in all three arguments: mu, tau and phi.
-    Discussed in sections 3.7 and 6.3 in the Comprehensive Documentation.
+    """Polynomial (Barycentric) interpolation with respect to ``mu``. The output 
+    is a function that is continuous and variable in all three arguments: ``mu``, ``tau`` and ``phi``.
+    Discussed in sections 3.7 and 6.3 of the Comprehensive Documentation.
 
     Parameters
     ----------
@@ -611,22 +618,23 @@ def interpolate(u):
          
 
 
-def to_diag_ordered_form(A, sym_offset):
+def to_diag_ordered_form(A, Nsuperdiags, Nsubdiags):
     """
-    Convert a matrix A to the diagonal ordered form required by ``scipy.linalg.solve_banded``.
-    We assume that the matrix has the same number of super- and sub-diagonals.
+    Convert some matrix A to the diagonal ordered form required by ``scipy.linalg.solve_banded``.
 
     Parameters
     ----------
     A : 2darray
         The square matrix to be converted.
-    sym_offset : int
-        The number of super- or sub-diagonals (assumed to be equal)
+    Nsuperdiags : int
+        The number of super-diagonals.
+    Nsubdiags : int
+        The number of sub-diagonals.
 
     Returns
     -------
     2darray
-        The diagonal ordered form matrix as required by solve_banded.
+        The diagonal ordered form matrix as required by ``scipy.linalg.solve_banded``.
     """
     n = A.shape[0]
     indices = np.arange(n)
@@ -634,28 +642,29 @@ def to_diag_ordered_form(A, sym_offset):
     return np.concatenate(
         [
             A[
-                indices - np.arange(sym_offset, -1, -1)[:, None],
+                indices - np.arange(Nsuperdiags, -1, -1)[:, None],
                 indices[None, :],
             ],
             A[
-                indices - np.arange(n - 1, n - sym_offset - 1, -1)[:, None],
+                indices - np.arange(n - 1, n - Nsubdiags - 1, -1)[:, None],
                 indices[None, :],
             ],
         ],
         axis=0,
     )
 
+
     
-def _mathscr_v(tau,                             # Input optical depths
-                l,                              # Layer index of each input optical depth
-                Nscoeffs,                       # Number of isotropic source polynomial coefficients
-                s_poly_coeffs,                  # Polynomial coefficients of isotropic source
-                G,                              # Eigenvector matrices
-                K,                              # Eigenvalues
-                G_inv,                          # Inverse of eigenvector matrix
-                mu_arr,                         # Quadrature nodes for both hemispheres
+def _mathscr_v(tau,                              # Input optical depths
+                l,                               # Layer index of each input optical depth
+                Nscoeffs,                        # Number of isotropic source polynomial coefficients
+                s_poly_coeffs,                   # Polynomial coefficients of isotropic source
+                G,                               # Eigenvector matrices
+                K,                               # Eigenvalues
+                G_inv,                           # Inverse of eigenvector matrix
+                mu_arr,                          # Quadrature nodes for both hemispheres
                 is_antiderivative_wrt_tau=False, # Switch to an antiderivative of the function?
-                autograd_compatible=False,      # Should the output functions be compatible with autograd?
+                autograd_compatible=False,       # Should the output functions be compatible with autograd?
                 ):
     """Particular solution for isotropic internal sources.
     Refer to section 3.6.1 of the Comprehensive Documentation.
@@ -664,22 +673,22 @@ def _mathscr_v(tau,                             # Input optical depths
     and ``_solve_for_coeffs`` functions which call it.
     
     Arguments of _mathscr_v
-    |          Variable           |                 Shape                 |
-    | --------------------------- | ------------------------------------- |
-    | ``tau``                       | ``Ntau``                                |
-    | ``l``                         | ``Ntau``                                |
-    | ``Nscoeffs``                  | scalar                                |
-    | ``s_poly_coeffs``             | ``NLayers x Nscoeffs`` or ``Nscoeffs``    |
-    | ``G``                         | ``NLayers<= x NQuad x NQuad``           |
-    | ``K``                         | ``NLayers<= x NQuad``                   |
+    |          Variable             |                   Shape                   |
+    | ----------------------------- | ----------------------------------------- |
+    | ``tau``                       | ``Ntau``                                  |
+    | ``l``                         | ``Ntau``                                  |
+    | ``Nscoeffs``                  | scalar                                    |
+    | ``s_poly_coeffs``             | ``NLayers x Nscoeffs``                    |
+    | ``G``                         | ``NLayers<= x NQuad x NQuad``             |
+    | ``K``                         | ``NLayers<= x NQuad``                     |
     | ``G_inv``                     | ``NLayers<= x NQuad x NQuad`` or ``None`` |
-    | ``mu_arr``                    | ``NQuad``                               |
-    | ``is_antiderivative_wrt_tau`` | boolean                               |
-    | ``autograd_compatible``      | boolean                               |
+    | ``mu_arr``                    | ``NQuad``                                 |
+    | ``is_antiderivative_wrt_tau`` | boolean                                   |
+    | ``autograd_compatible``       | boolean                                   |
     
     Notable internal variables of _mathscr_v
-    |     Variable     |                Shape                | 
-    | ---------------- | ----------------------------------- |
+    |     Variable     |                Shape                  | 
+    | ---------------- | ------------------------------------- |
     | i_arr            | ``Nscoeffs``                          |
     | i_arr_repeat     | ``Nscoeffs*(Nscoeffs+1)/2``           | Using triangular number formula
     | j_arr            | ``Nscoeffs*(Nscoeffs+1)/2``           | Using triangular number formula
@@ -694,8 +703,8 @@ def _mathscr_v(tau,                             # Input optical depths
         def mathscr_b(i):
             """
             Notable internal variables of mathscr_b
-            |     Variable     |                 Shape                 |
-            | ---------------- | ------------------------------------- |
+            |     Variable     |                  Shape                  |
+            | ---------------- | --------------------------------------- |
             | j_arr            | ``i + 1``                               |
             | s_poly_coeffs_nj | ``i + 1``                               |
             | OUTPUT           | ``Nscoeffs x (i + 1) x NQuad``          |
@@ -716,7 +725,7 @@ def _mathscr_v(tau,                             # Input optical depths
         shape = np.shape(K)
         i_arr = np.arange(Nscoeffs)
         i_arr_repeat = np.repeat(i_arr, i_arr + 1)
-        j_arr = np.concatenate([np.arange(i + 1) for i in range(Nscoeffs)])
+        j_arr = np.concatenate([i_arr[:i] for i in range(1, Nscoeffs + 1)])
         s_poly_coeffs_nj = s_poly_coeffs[:, n - j_arr]
 
         mathscr_v_coeffs = np.zeros((Nscoeffs, shape[0], shape[1]))
@@ -752,7 +761,7 @@ def _mathscr_v(tau,                             # Input optical depths
 
 def _compare(results, mu_to_compare, reorder_mu, flux_up, flux_down, u=None):
     """Performs pointwise comparisons between results from Stamnes' DISORT,
-    which are stored in .npz files, against results from PythonicDISORT. Used in our PyTests.
+    which are stored in ``.npz`` files, against results from PythonicDISORT. Used in our PyTests.
 
     """
     # Load saved results from Stamnes' DISORT
